use fantoccini::{elements::Element, ClientBuilder, Locator};

/// Holds data about stackoverflow answers
#[derive(Debug, Clone)]
struct Answer {
    upvotes: u32,
    author: String,
    content: String,
}

/// Get all answers from a stackoverflow domain. No error handling is done so get ready to either
/// check your input or "note: run with `RUST_BACKTRACE=1` environment variable to display a
/// backtrace"
async fn get_answers(url: &str) -> Vec<Answer> {
    let c = ClientBuilder::native()
        .connect("http://localhost:4444")
        .await
        .expect("failed to connect to WebDriver");

    // first, go to the Wikipedia page for Foobar
    c.goto(url).await.unwrap();

    let answer_loc = c.find_all(Locator::Css(".answer")).await.unwrap();
    let mut out_answers = vec![];
    for answer in answer_loc {
        let text = answer.text().await.unwrap();

        let score = text
            .clone()
            .split('\n')
            .collect::<Vec<&str>>()
            .get(0)
            .unwrap()
            .parse::<u32>()
            .unwrap();
        let content = text;

        out_answers.push(Answer {
            upvotes: score,
            content,
            author: "unimplemented".to_string(),
        });
    }
    c.close().await.unwrap();

    out_answers
}

#[tokio::main]
async fn main() {
    dbg!(get_answers("https://stackoverflow.com/questions/11227809/why-is-processing-a-sorted-array-faster-than-processing-an-unsorted-array").await);
}
